@@ -21,9 +21,9 @@
 
 import enum
 
-class PresentationMode(enum.Enum):
-	Interactive = "interactive"
-	Static = "static"
-
 class PresentationFeature(enum.Enum):
+	Interactive = "interactive"
 	Timer = "timer"
+	Info = "info"
+	Pygments = "pygments"
+	Acronyms = "acronyms"
