@@ -20,15 +20,16 @@
 #	Johannes Bauer <JohannesBauer@gmx.de>
 
 import os
-from .Enums import PresentationMode
 from .FileLookup import FileLookup
 
 class RenderingParameters():
-	def __init__(self, template_style = "default", honor_pauses = True, collapse_animation = False, presentation_mode = PresentationMode.Interactive, extra_template_dirs = None, include_dirs = None, index_filename = "index.html", geometry = (1280, 720), image_max_dimension = 1920, presentation_features = None, injected_metadata = None):
+	def __init__(self, template_style = "default", template_style_opts = None, honor_pauses = True, collapse_animation = False, extra_template_dirs = None, include_dirs = None, index_filename = "index.html", resource_uri = "", geometry = (1280, 720), image_max_dimension = 1920, presentation_features = None, injected_metadata = None):
 		self._template_style = template_style
+		self._template_style_opts = template_style_opts
+		if self._template_style_opts is None:
+			self._template_style_opts = [ ]
 		self._honor_pauses = honor_pauses
 		self._collapse_animation = collapse_animation
-		self._presentation_mode = presentation_mode
 		template_dirs = [ os.path.expanduser("~/.config/pyradium/templates"), os.path.dirname(os.path.realpath(__file__)) + "/templates" ]
 		if extra_template_dirs is not None:
 			template_dirs += extra_template_dirs
@@ -38,6 +39,7 @@ class RenderingParameters():
 		else:
 			self._include_dirs = FileLookup(include_dirs)
 		self._index_filename = index_filename
+		self._resource_uri = resource_uri
 		self._geometry = geometry
 		self._image_max_dimension = image_max_dimension
 		self._presentation_features = set(presentation_features) if (presentation_features is not None) else set()
@@ -47,6 +49,10 @@ class RenderingParameters():
 	def template_style(self):
 		return self._template_style
 
+	@property
+	def template_style_opts(self):
+		return self._template_style_opts
+
 	@property
 	def honor_pauses(self):
 		return self._honor_pauses
@@ -55,10 +61,6 @@ class RenderingParameters():
 	def collapse_animation(self):
 		return self._collapse_animation
 
-	@property
-	def presentation_mode(self):
-		return self._presentation_mode
-
 	@property
 	def template_dirs(self):
 		return self._template_dirs
@@ -71,6 +73,10 @@ class RenderingParameters():
 	def index_filename(self):
 		return self._index_filename
 
+	@property
+	def resource_uri(self):
+		return self._resource_uri
+
 	@property
 	def geometry_x(self):
 		return self._geometry[0]
