@@ -42,6 +42,10 @@ class SlideSubset {
 	get end_slide() {
 		return this._end_slide;
 	}
+
+	get slide_count() {
+		return this.end_slide - this.begin_slide + 1;
+	}
 }
 
 class SlideSubsetSelector {
@@ -213,6 +217,7 @@ export class PresentationTimer {
 		this._bc = new BroadcastChannel("presentation");
 		this._bc.addEventListener("message", (msg) => this._rx_message(msg));
 		this._nominal_presentation_duration_secs = null;
+		this._presentation_duration_secs = null;
 		this._slide_subset_selector = null;
 		this._current_slide = null;
 		this._meta = null;
@@ -222,6 +227,7 @@ export class PresentationTimer {
 		this._timeout_handle = null;
 		this._have_connection = false;
 		this._active_timer = null;
+		this._dynamic_timer = null;
 		this._reset_timeout();
 		this._initialize_ui();
 		setInterval(() => this._ui_update_display(), 1000);
@@ -232,7 +238,8 @@ export class PresentationTimer {
 		this._ui_elements.presentation_end_time.addEventListener("input", (event) => this._ui_update_everything());
 		this._ui_elements.slide_subset.addEventListener("input", (event) => this._ui_update_everything());
 		this._ui_elements.btn_arm_timer.addEventListener("click", (event) => this.arm_timer());
-		this._ui_elements.btn_start_stop_timer.addEventListener("click", (event) => this.start_stop_timer());
+		this._ui_elements.btn_start_timer.addEventListener("click", (event) => this.start_timer());
+		this._ui_elements.main_indicator.addEventListener("click", (event) => this.stop_timer());
 		this._ui_update_everything();
 	}
 
@@ -253,32 +260,33 @@ export class PresentationTimer {
 			}
 		}
 
-		let duration_secs = null;
 		if (this._presentation_end_time != null) {
 			const end_ts = this._presentation_end_time.compute(this._nominal_presentation_duration_secs);
 			const hh_mm_str = end_ts.getHours() + ":" + end_ts.getMinutes().toString().padStart(2, "0");
 			const now = new Date();
-			duration_secs = (end_ts.getTime() - now.getTime()) / 1000;
+			this._presentation_duration_secs = (end_ts.getTime() - now.getTime()) / 1000;
 			this._ui_elements.presentation_end_time_display.innerText = hh_mm_str;
-			this._ui_elements.presentation_duration_display.innerText = TimeTools.format_hm(duration_secs);
+			this._ui_elements.presentation_duration_display.innerText = TimeTools.format_hm(this._presentation_duration_secs);
 		} else {
 			this._ui_elements.presentation_end_time_display.innerText = "-";
 			this._ui_elements.presentation_duration_display.innerText = "-";
+			this._presentation_duration_secs = null;
 		}
 
-		let nominal_slide_duration_secs = null;
-		if (this._slide_subset != null) {
-			nominal_slide_duration_secs = this._compute_nominal_slide_duration_secs();
+		let nominal_subset_duration_secs = this._compute_nominal_subset_duration_secs();
+		if (nominal_subset_duration_secs != null) {
+			const average_slide_duration_secs = nominal_subset_duration_secs / this._slide_subset.slide_count;
 			this._ui_elements.slide_subset_display.innerText = this._slide_subset.begin_slide + " - " + this._slide_subset.end_slide;
 			this._ui_elements.slide_count_display.innerText = this._slide_subset.end_slide - this._slide_subset.begin_slide + 1;
-			this._ui_elements.nominal_slide_duration_display.innerText = TimeTools.format_hm(nominal_slide_duration_secs);
+			this._ui_elements.average_slide_duration_display.innerText = TimeTools.format_ms(average_slide_duration_secs);
 		} else {
 			this._ui_elements.slide_subset_display.innerText = "-";
 			this._ui_elements.slide_count_display.innerText = "-";
-			this._ui_elements.nominal_slide_duration_display.innerText = "-";
+			this._ui_elements.average_slide_duration_display.innerText = "-";
 		}
+
 		if ((this._presentation_end_time != null) && (this._slide_subset != null)) {
-			const pace_percent = nominal_slide_duration_secs / duration_secs * 100;
+			const pace_percent = nominal_subset_duration_secs / this._presentation_duration_secs * 100;
 			this._ui_elements.presentation_pace_display.innerText = pace_percent.toFixed(0) + "%";
 		} else {
 			this._ui_elements.presentation_pace_display.innerText = "-";
@@ -290,30 +298,27 @@ export class PresentationTimer {
 		switch (this._timer_mode) {
 			case TimerMode.STOPPED:
 				this._ui_elements.btn_arm_timer.innerText = "Arm Timer";
-				this._ui_elements.btn_start_stop_timer.innerText = "Start Timer";
 				this._ui_elements.btn_arm_timer.disabled = !time_and_slides_set;
-				this._ui_elements.btn_start_stop_timer.disabled = !time_and_slides_set;
 				this._ui_elements.presentation_end_time.disabled = false;
 				this._ui_elements.slide_subset.disabled = false;
+				this._ui_elements.timer_inactive_menu.style.display = "";
 				break;
 
 			case TimerMode.ARMED:
 				this._ui_elements.btn_arm_timer.disabled = false;
 				this._ui_elements.btn_arm_timer.innerText = "Disarm Timer";
-				this._ui_elements.btn_start_stop_timer.innerText = "Start Timer";
 				this._ui_elements.btn_arm_timer.disabled = false;
-				this._ui_elements.btn_start_stop_timer.disabled = false;
 				this._ui_elements.presentation_end_time.disabled = true;
 				this._ui_elements.slide_subset.disabled = true;
+				this._ui_elements.timer_inactive_menu.style.display = "";
 				break;
 
 			case TimerMode.STARTED:
 				this._ui_elements.btn_arm_timer.innerText = "Arm Timer";
-				this._ui_elements.btn_start_stop_timer.innerText = "Stop Timer";
 				this._ui_elements.btn_arm_timer.disabled = true;
-				this._ui_elements.btn_start_stop_timer.disabled = false;
 				this._ui_elements.presentation_end_time.disabled = true;
 				this._ui_elements.slide_subset.disabled = true;
+				this._ui_elements.timer_inactive_menu.style.display = "none";
 				break;
 		}
 	}
@@ -345,34 +350,54 @@ export class PresentationTimer {
 			return;
 		}
 
-		const now = new Date();
-		const remaining_presentation_time_secs = (this._active_timer.presentation_end.getTime() - now.getTime()) / 1000;
-		const elapsed_time_secs = (now.getTime() - this._active_timer.presentation_start.getTime()) / 1000;
+		const now = new Date().getTime();
+		const remaining_presentation_time_secs = (this._active_timer.presentation_end.getTime() - now) / 1000;
+		const nominal_elapsed_time_secs = (now - this._active_timer.presentation_start.getTime()) / 1000;
+		const dynamic_elapsed_time_secs = (now - this._dynamic_timer.presentation_start.getTime()) / 1000;
+		const position_based_on_time_percent = nominal_elapsed_time_secs / this._active_timer.presentation_duration_secs * 100;
+		const remaining_slide_count = this._active_timer.slide_subset.slide_count - (this._current_slide - this._active_timer.slide_subset.begin_slide + 1);
+		const presentation_end_hh_mm_str = this._active_timer.presentation_end.getHours() + ":" + this._active_timer.presentation_end.getMinutes().toString().padStart(2, "0");
 
-		this._ui_elements.presentation_time_display.innerText = TimeTools.format_hms(this._active_timer.presentation_duration_secs);
-		this._ui_elements.elapsed_time_display.innerText = TimeTools.format_hms(elapsed_time_secs);
-		this._ui_elements.remaining_time_display.innerText = TimeTools.format_hms(remaining_presentation_time_secs);
+		this._ui_elements.presentation_time_display.innerHTML = TimeTools.format_hms(this._active_timer.presentation_duration_secs) + "<br />until " + presentation_end_hh_mm_str;
+		this._ui_elements.elapsed_time_display.innerHTML = TimeTools.format_hms(nominal_elapsed_time_secs) + "<br />" + position_based_on_time_percent.toFixed(0) + "%";
+		this._ui_elements.remaining_display.innerHTML = TimeTools.format_hms(remaining_presentation_time_secs) + "<br />" + remaining_slide_count + " slides";
 
 		const current_slide_ratio = this._slide_subset_selector.get_ratio_of(this._current_slide);
 		const current_slide_nominal_duration_secs = current_slide_ratio / this._active_timer.subset_ratio * this._active_timer.presentation_duration_secs;
-		this._ui_elements.slide_time_display.innerText = TimeTools.format_hms(current_slide_nominal_duration_secs);
+		const current_slide_dynamic_duration_secs = current_slide_ratio / this._dynamic_timer.subset_ratio * this._dynamic_timer.presentation_duration_secs;
+		this._ui_elements.slide_time_display.innerHTML = "nominal " + TimeTools.format_hms(current_slide_nominal_duration_secs) + "<br />dynamic " + TimeTools.format_hms(current_slide_dynamic_duration_secs);
 
-
-		const subset_begin_ratio = this._slide_subset_selector.get_cumulative_ratio_before(this._active_timer.slide_subset.begin_slide);
 		const cumulative_current_slide_ratio = this._slide_subset_selector.get_cumulative_ratio_before(this._current_slide);
-		const current_completion_ratio = (cumulative_current_slide_ratio - subset_begin_ratio) / this._active_timer.subset_ratio;
-		const nominal_elapsed_time_secs = current_completion_ratio * this._active_timer.presentation_duration_secs;
 
-		const delta_time_secs = nominal_elapsed_time_secs - elapsed_time_secs + current_slide_nominal_duration_secs;
-		this._ui_elements.delta_time_display.innerText = TimeTools.format_hms(delta_time_secs);
+		const nominal_subset_begin_ratio = this._slide_subset_selector.get_cumulative_ratio_before(this._active_timer.slide_subset.begin_slide);
+		const nominal_current_completion_ratio = (cumulative_current_slide_ratio - nominal_subset_begin_ratio) / this._active_timer.subset_ratio;
+		const ideal_nominal_elapsed_time_secs = nominal_current_completion_ratio * this._active_timer.presentation_duration_secs;
+
+		const dynamic_subset_begin_ratio = this._slide_subset_selector.get_cumulative_ratio_before(this._dynamic_timer.slide_subset.begin_slide);
+		const dynamic_current_completion_ratio = (cumulative_current_slide_ratio - dynamic_subset_begin_ratio) / this._dynamic_timer.subset_ratio;
+		const ideal_dynamic_elapsed_time_secs = dynamic_current_completion_ratio * this._dynamic_timer.presentation_duration_secs;
+
+		const nominal_delta_time_secs = ideal_nominal_elapsed_time_secs - nominal_elapsed_time_secs + current_slide_nominal_duration_secs;
+		const dynamic_delta_time_secs = ideal_dynamic_elapsed_time_secs - dynamic_elapsed_time_secs + current_slide_dynamic_duration_secs;
+		if (this._current_slide <= this._dynamic_timer.slide_subset.end_slide) {
+			this._ui_elements.dynamic_delta_time_display.innerText = TimeTools.format_hms(dynamic_delta_time_secs);
+		} else {
+			/* Dynamic timings do not make sense when exceeding the subset, so default to the nominal timing then */
+			this._ui_elements.dynamic_delta_time_display.innerText = TimeTools.format_hms(nominal_delta_time_secs);
+		}
+		this._ui_elements.nominal_delta_time_display.innerText = TimeTools.format_hms(nominal_delta_time_secs);
+
+		const current_slide_no_within_subset = this._current_slide - this._active_timer.slide_subset.begin_slide + 1;
+		const position_based_on_slides = (this._current_slide - this._active_timer.slide_subset.begin_slide + 1) / this._active_timer.slide_subset.slide_count * 100;
+		this._ui_elements.slide_position_display.innerHTML = current_slide_no_within_subset + "/" + this._active_timer.slide_subset.slide_count + "<br />" + position_based_on_slides.toFixed(0) + "%";
 
 		let speed_error_secs = 0;
-		if (delta_time_secs > current_slide_nominal_duration_secs) {
+		if (nominal_delta_time_secs > current_slide_nominal_duration_secs) {
 			/* We're too fast. Speed error is positive. */
-			speed_error_secs = delta_time_secs - current_slide_nominal_duration_secs;
-		} else if (delta_time_secs < 0) {
+			speed_error_secs = nominal_delta_time_secs - current_slide_nominal_duration_secs;
+		} else if (nominal_delta_time_secs < 0) {
 			/* We're too slow. Speed error is negative. */
-			speed_error_secs = delta_time_secs;
+			speed_error_secs = nominal_delta_time_secs;
 		}
 
 		this._ui_elements.main_indicator.className = "main_indicator";
@@ -397,12 +422,13 @@ export class PresentationTimer {
 		this._ui_update_display();
 	}
 
-	_compute_nominal_slide_duration_secs() {
-		if (this._slide_subset == null) {
+	_compute_nominal_subset_duration_secs() {
+		if ((this._slide_subset == null) || (this._presentation_duration_secs == null)) {
 			return null;
 		}
-		const ratio = this._slide_subset_selector.get_ratio_of_subset(this._slide_subset);
-		return ratio * this._nominal_presentation_duration_secs;
+		const subset_ratio = this._slide_subset_selector.get_ratio_of_subset(this._slide_subset);
+		const nominal_subset_duration_secs = subset_ratio * this._nominal_presentation_duration_secs;
+		return nominal_subset_duration_secs;
 	}
 
 	_reset_timeout() {
@@ -452,6 +478,7 @@ export class PresentationTimer {
 			this._current_slide = data.data.current_slide;
 			if (slide_change) {
 				this.start_timer_if_armed();
+				this._recompute_dynamic_timer();
 			}
 			if (update_ui) {
 				this._ui_update_display();
@@ -466,20 +493,24 @@ export class PresentationTimer {
 		}
 	}
 
-	start_timer() {
-		if (this._timer_mode == TimerMode.STARTED) {
-			return;
-		}
-
-		this._timer_mode = TimerMode.STARTED;
-		this._active_timer = {
+	_create_timer_object(is_dynamic_timer = false) {
+		let timer_object = {
 			presentation_start: new Date(),
-			presentation_end: TimeTools.parse_timestamp(this._ui_elements.presentation_end_time.value).compute(this._nominal_presentation_duration_secs),
-			slide_subset: this._slide_subset_selector.parse(this._ui_elements.slide_subset.value, (this._meta == null) ? null : this._meta.slide_count),
 		};
+		if (!is_dynamic_timer) {
+			timer_object.presentation_end = TimeTools.parse_timestamp(this._ui_elements.presentation_end_time.value).compute(this._nominal_presentation_duration_secs);
+			timer_object.slide_subset = this._slide_subset_selector.parse(this._ui_elements.slide_subset.value, (this._meta == null) ? null : this._meta.slide_count);
+		} else {
+			timer_object.presentation_end = this._active_timer.presentation_end;
+			timer_object.slide_subset = new SlideSubset((this._current_slide <= this._active_timer.slide_subset.end_slide) ? this._current_slide : this._active_timer.slide_subset.end_slide, this._active_timer.slide_subset.end_slide);
+		}
+		timer_object.presentation_duration_secs = (timer_object.presentation_end.getTime() - timer_object.presentation_start.getTime()) / 1000;
+		timer_object.subset_ratio = this._slide_subset_selector.get_ratio_of_subset(timer_object.slide_subset);
+		return timer_object;
+	}
 
-		this._active_timer.presentation_duration_secs = (this._active_timer.presentation_end.getTime() - this._active_timer.presentation_start.getTime()) / 1000;
-		this._active_timer.subset_ratio = this._slide_subset_selector.get_ratio_of_subset(this._active_timer.slide_subset);
+	_recompute_dynamic_timer() {
+		this._dynamic_timer = this._create_timer_object(true);
 	}
 
 	start_timer_if_armed() {
@@ -502,18 +533,24 @@ export class PresentationTimer {
 		this._ui_update_everything();
 	}
 
-	start_stop_timer() {
-		console.log("Start timer.");
-
-		if ((this._timer_mode == TimerMode.STOPPED) || (this._timer_mode == TimerMode.ARMED)) {
-			/* Starting timer */
-			this.start_timer();
-		} else if (this._timer_mode == TimerMode.STARTED) {
-			/* Stopping timer */
-			this._timer_mode = TimerMode.STOPPED;
-			this._current_slide = null;
-			this._active_timer = null;
+	start_timer() {
+		if (this._timer_mode == TimerMode.STARTED) {
+			return;
 		}
+
+		console.log("Start timer.");
+		this._timer_mode = TimerMode.STARTED;
+		this._active_timer = this._create_timer_object();
+		this._dynamic_timer = this._active_timer;
+		this._ui_update_everything();
+	}
+
+	stop_timer() {
+		console.log("Stop timer.");
+		this._timer_mode = TimerMode.STOPPED;
+		this._current_slide = null;
+		this._active_timer = null;
+		this._dynamic_timer = null;
 		this._ui_update_everything();
 	}
 }
