@@ -1,5 +1,5 @@
 #	pyradium - HTML presentation/slide show generator
-#	Copyright (C) 2015-2021 Johannes Bauer
+#	Copyright (C) 2015-2022 Johannes Bauer
 #
 #	This file is part of pyradium.
 #
@@ -29,6 +29,7 @@ _log = logging.getLogger(__spec__.name)
 class XMLHookRegistry():
 	_HOOKS = { }
 	_SPECIAL = set([ "var", "pause", "content" ])
+	_BREAK_DESCENT_ON = set([ "s:verb", "s:term", "s:code" ])
 
 	@classmethod
 	def register_hook(cls, hook_class):
@@ -62,11 +63,13 @@ class XMLHookRegistry():
 							pass
 						else:
 							XMLTools.replace_node(node, replace_by)
-							if not isinstance(replace_by, list):
-								XMLTools.walk(replace_by, callback)
-							else:
-								for new_child in replace_by:
-									XMLTools.walk(new_child, callback)
+							continue_descent_with_replaced_elements = node.nodeName not in cls._BREAK_DESCENT_ON
+							if continue_descent_with_replaced_elements:
+								if not isinstance(replace_by, list):
+									XMLTools.walk(replace_by, callback)
+								else:
+									for new_child in replace_by:
+										XMLTools.walk(new_child, callback)
 					else:
 						_log.warning("Unknown hook '%s' used in source document.", hook_name)
 			elif node.nodeType == node.TEXT_NODE:
