@@ -1,5 +1,5 @@
 #	pyradium - HTML presentation/slide show generator
-#	Copyright (C) 2015-2021 Johannes Bauer
+#	Copyright (C) 2015-2022 Johannes Bauer
 #
 #	This file is part of pyradium.
 #
@@ -27,6 +27,7 @@ from .TexHook import TexHook
 from .TerminalHook import TerminalHook
 from .CodeHook import CodeHook
 from .ImgHook import ImgHook
+from .PlotHook import PlotHook
 from .AcronymHook import AcronymHook
 from .TimeHook import TimeHook
 from .ExecHook import ExecHook
@@ -35,3 +36,5 @@ from .DebugHook import DebugHook
 from .NthHook import NthHook
 from .LinkHook import LinkHook
 from .NoSpellcheckHook import NoSpellcheckHook
+from .NoLinebreakHook import NoLinebreakHook
+from .VerbatimHook import VerbatimHook
